package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.DERBoolean;
import java.io.IOException;

public class X509Extension {
   boolean critical;
   ASN1OctetString value;

   public X509Extension(DERBoolean critical, ASN1OctetString value) {
      this.critical = critical.isTrue();
      this.value = value;
   }

   public X509Extension(boolean critical, ASN1OctetString value) {
      this.critical = critical;
      this.value = value;
   }

   public static ASN1Object convertValueToObject(X509Extension ext) {
      try {
         return ASN1Object.fromByteArray(ext.getValue().getOctets());
      } catch (IOException var1) {
         throw new IllegalArgumentException("can't convert extension: " + var1);
      }
   }

   public boolean isCritical() {
      return this.critical;
   }

   public ASN1OctetString getValue() {
      return this.value;
   }

   public int hashCode() {
      return this.isCritical() ? this.getValue().hashCode() : ~this.getValue().hashCode();
   }

   public boolean equals(Object o) {
      if (!(o instanceof X509Extension)) {
         return false;
      } else {
         X509Extension o1;
         return (o1 = (X509Extension)o).getValue().equals(this.getValue()) && o1.isCritical() == this.isCritical();
      }
   }
}
